#
# spec file for package libmodbus
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libmodbus
Version:        3.1.11
Release:        1.3
Summary:        Modbus Library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.libmodbus.org/
Source:         https://github.com/stephane/libmodbus/releases/download/v%{version}/libmodbus-%{version}.tar.gz
BuildRequires:  asciidoc
BuildRequires:  pkgconfig
BuildRequires:  xmlto

%description
libmodbus is a free software library to send/receive data with a device which
respects the Modbus protocol. This library can use a serial port or an Ethernet
connection.

The functions included in the library have been derived from the Modicon Modbus
Protocol Reference Guide which can be obtained from Schneider.

%package -n libmodbus5
Summary:        Modbus Library
Group:          System/Libraries

%description -n libmodbus5
libmodbus is a free software library to send/receive data with a device which
respects the Modbus protocol. This library can use a serial port or an Ethernet
connection.

The functions included in the library have been derived from the Modicon Modbus
Protocol Reference Guide which can be obtained from Schneider.

%package devel
Summary:        Development Files for Modbus Library
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libmodbus5 = %{version}

%description devel
libmodbus is a free software library to send/receive data with a device which
respects the Modbus protocol. This library can use a serial port or an Ethernet
connection.

The functions included in the library have been derived from the Modicon Modbus
Protocol Reference Guide which can be obtained from Schneider.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
%configure\
	--docdir=%{_docdir}/%{name}\
	--disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# Installed by %%doc
rm %{buildroot}%{_docdir}/%{name}/{AUTHORS,NEWS,README.md}

%post -n libmodbus5 -p /sbin/ldconfig
%postun -n libmodbus5 -p /sbin/ldconfig

%files -n libmodbus5
%license COPYING.LESSER
%doc AUTHORS NEWS README.md
%{_libdir}/*.so.5*

%files devel
%{_includedir}/modbus
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Oct 22 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.1.11
  * RTU - Check CRC before filtering on slave ID.
  * HAVE_NETINET_IN_H as guard around header.
  * Use default port 502 in documentation.
  * Fix float endianness issue introduced in v3.1.8
  * Proper display of used CFLAGS.
  * Don't build with debug flag by default anymore.
  * Check request length in modbus_reply when used in memcpy.
  * Fix insecure data handling. CID 416366: INTEGER_OVERFLOW found
    with Coverity Scan.
  * Remove useless cast in setsockopt call.
  * Documentation improvements.
  * Revert TCP checks for recovery.
  * Don't use loop initial declaration.
  * Don't use gai_strerror if not available.
  * Add checks for netinet/ip.h and gai_strerror.
  * Log error in read input registers if debug.
  * Fix errno value on timeout with TCP connect.
  * Free addrinfo struct on getaddrinfo() gerrors.
  * Fix doc of modbus_mapping_new_start_address.
* Sat Jan 21 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.10:
  * Fix baud rate handling with RTU under Linux
  * Fix modbus_disable_quirks signature
  * Move content about migration to libmodbus.org
  * Avoid negative value in FD_SET call
  * Test socket against positive value instead of -1
  * Improvements to autotools by @ndim
  * Fix doc links by @jordanjohnson56 (#653)
  * Test the protocol id for 0 by @metapsychologe (#509)
  * Fix double negative in tests
  * New quirks handler (closes #38 #533)
  * Fix bitwise OR in documentation
  * Improve doc about slave ID in RTU
  * Add .clang-format and format code (closes #394)
  * Remove constraints on baud rate values
  * Accept IP or device in arg of unit test progs
  * Avoid compilation issue with VS2022 with strdup
  * Display created files in configure.js
  * Use strcpy_s under Windows
  * Replace inet_addr by inet_pton calls
  * Replace inet_ntoa by inet_ptop
  * Update configure.ac/config.h.win32 for new inet functions
  * Instructions to build libmodbus in a VS project
  * Fix connection check for Windows RTU (closes #660, #662)
  * Add CIFuzz Github action by @DavidKorczynski (#669)
  * Convert a few int to unsigned int (#402)
* Fri Dec  2 2022 Dirk Müller <dmueller@suse.com>
- update to 3.1.8:
  * Major rewrite of documentation with Material for mkdocs
  * Reduce memory use of TCP PI backend (closes #621)
  * Fixed MODBUS_ERROR_RECOVERY_LINK not working on Windows (@embeddedmz)
  * Replace Travis CI by GitHub CI
  * Fix linker error for Windows (VCLinkerTool)
  * Address check in single register / coil responses added (#463)
  * Swap CRC bytes in request data but not at CRC computing (#397)
  * Fix float endianness issue on big endian architecture
  * Fix comment about EMBUNKEXC (closes #566)
  * Fix network library detection on Haiku
  * Fix typos (closes #620)
* Thu Feb  3 2022 Stanislav Brabec <sbrabec@suse.com>
- Update to version 3.1.7:
  * Many minor fixes, typo fixes and documentation enhancements.
  * For more see NEWS.
- Properly build debug package.
* Wed Aug  7 2019 sbrabec@suse.com
- Update to version 3.1.6:
  - API extensions and minor API changes
  - Fix VD-1301 and VD-1302 vulnerabilities.
  - Bug fixes.
  * For more see NEWS.
* Thu Apr 20 2017 sbrabec@suse.com
- New package, version 3.1.4 (development, but stable).
